# Generating and contributing to the documentation

## Building the docs locally

The full process is explained in the ["contributing" page of the online doc](https://airbus.github.io/decomon/main/contribute.html#building-the-docs-locally),
also available [here locally](source/contribute.md#building-the-docs-locally).

## Guidelines when writing the documentation

Hints to [write the documentation](source/contribute.md#writing-the-documentation) and [contribute to the notebooks](source/contribute.md#notebooks) are also available on the
["contributing" page](https://airbus.github.io/decomon/main/contribute.html#guidelines-to-follow-when-preparing-a-contribution).
